@@ -25,19 +25,6 @@ const CURRENT_EXE: &str = "tp-note";
 /// Tp-Note's configuration file filename.
 const CONFIG_FILENAME: &str = "tp-note.toml";
 
-/// File extension of `to-note` files.
-pub const EXTENSION_DEFAULT: &str = "md";
-
-/// _Tp-Note_ opens all `.md` files with an external editor. It recognizes its
-/// own files, by the file extension `.md`, by a valid YAML header and the
-/// presence of a "title" variable*). When set to `false`, popup alert windows
-/// inform the user about missing headers. `true` suppresses the popup alert
-/// windows and the text editor starts without further notification.
-/// See also `VIEWER_MISSING_HEADER_DISABLES`.
-///
-/// *) all string literals given in this example are configurable.
-const SILENTLY_IGNORE_MISSING_HEADER: bool = true;
-
 /// Default value for command line option `--debug`.  Determines the maximum
 /// debug level events must have, to be logged.  If the command line option
 /// `--debug` is present, its value will be used instead.
@@ -59,7 +46,61 @@ const ARG_DEFAULT_NO_FILENAME_SYNC: bool = false;
 /// `--debug=off`).
 const ARG_DEFAULT_POPUP: bool = true;
 
-/// The variables `NOTE_FILE_EXTENSIONS_*` list file extensions that Tp-Note
+/// Maximum length of a note's filename in bytes. If a filename template produces
+/// a longer string, it will be truncated.
+#[cfg(not(test))]
+pub const FILENAME_LEN_MAX: usize =
+    // Most file system's limit.
+    255
+    // Additional separator.
+    - FILENAME_COPY_COUNTER_EXTRA_SEPARATOR.len()
+    // Additional copy counter.
+    - FILENAME_COPY_COUNTER_OPENING_BRACKETS.len() - 2 - FILENAME_COPY_COUNTER_CLOSING_BRACKETS.len()
+    // Extra spare bytes, in case the user's copy counter is longer.
+    - 6;
+#[cfg(test)]
+pub const FILENAME_LEN_MAX: usize = 10;
+
+/// List of characters that can be part of a _sort tag_.
+/// This list must not include `SORT_TAG_EXTRA_SEPARATOR`.
+/// The first character in the filename which is not
+/// in this list, marks the end of the sort tag.
+const FILENAME_SORT_TAG_CHARS: &str = "0123456789.-_ \t";
+
+/// In case the file stem starts with a character in
+/// `SORT_TAG_CHARS` the `SORT_TAG_EXTRA_SEPARATOR`
+/// character is inserted in order to separate both parts
+/// when the filename is read next time.
+const FILENAME_SORT_TAG_EXTRA_SEPARATOR: char = '\'';
+
+/// If the stem of a filename ends with a pattern, that is similar
+/// to a copy counter, add this extra separator. Must be `-`, `_`
+/// or any combination of both. Shorter looks better.
+const FILENAME_COPY_COUNTER_EXTRA_SEPARATOR: &str = "-";
+
+/// Tp-Note may add a counter at the end of the filename when
+/// it can not save a file because the name is taken already.
+/// This is the opening bracket search pattern. Some examples:
+/// `"-"`, "'_'"", `"_-"`,`"-_"`, `"("`
+/// Can be empty.
+const FILENAME_COPY_COUNTER_OPENING_BRACKETS: &str = "(";
+
+/// Tp-Note may add a counter at the end of the filename when
+/// it can not save a file because the name is taken already.
+/// This is the closing bracket search pattern. Some examples:
+/// `"-"`, "'_'"", `"_-"`,`"-_"`, `"("`
+/// Can be empty.
+const FILENAME_COPY_COUNTER_CLOSING_BRACKETS: &str = ")";
+
+/// When a filename is taken already, Tp-Note adds a copy
+/// counter number in the range of `0..COPY_COUNTER_MAX`
+/// at the end.
+pub const FILENAME_COPY_COUNTER_MAX: usize = 400;
+
+/// File extension of new _Tp-Note_ files.
+pub const FILENAME_EXTENSION_DEFAULT: &str = "md";
+
+/// The variables `FILENAME_EXTENSIONSS_*` list file extensions that Tp-Note
 /// considers as its own note files.
 /// Tp-Note opens these files, reads their their YAML header and
 /// launches an external file editor and an file viewer
@@ -71,21 +112,21 @@ const ARG_DEFAULT_POPUP: bool = true;
 ///
 /// The present list contains file extensions of
 /// Markdown encoded Tp-Note files.
-pub const NOTE_FILE_EXTENSIONS_MD: &[&str] = &["md", "markdown", "markdn", "mdown", "mdtxt"];
+pub const FILENAME_EXTENSIONS_MD: &[&str] = &["md", "markdown", "markdn", "mdown", "mdtxt"];
 
 /// The present list contains file extensions of
 /// RestructuredText encoded Tp-Note files.
 ///
-/// See also `NOTE_FILE_EXTENSION_MD`.
-pub const NOTE_FILE_EXTENSIONS_RST: &[&str] = &["rst", "rest"];
+/// See also `FILENAME_EXTENSIONS_MD`.
+pub const FILENAME_EXTENSIONS_RST: &[&str] = &["rst", "rest"];
 
 /// The present list contains file extensions of
 /// HTML encoded Tp-Note files. For these
 /// file types their content is forwarded to the web browser
 /// without modification.
 ///
-/// See also `NOTE_FILE_EXTENSION_MD`.
-pub const NOTE_FILE_EXTENSIONS_HTML: &[&str] = &["htmlnote"];
+/// See also `FILENAME_EXTENSIONS_MD`.
+pub const FILENAME_EXTENSIONS_HTML: &[&str] = &["htmlnote"];
 
 /// The present list contains file extensions of
 /// Text encoded Tp-Note files that the viewer shows
@@ -93,30 +134,24 @@ pub const NOTE_FILE_EXTENSIONS_HTML: &[&str] = &["htmlnote"];
 /// Only hyperlinks in _Markdown_, _reStructuredText_, _Asciidoc_ and _HTML_ are
 /// rendered, thus clickable.
 ///
-/// See also `NOTE_FILE_EXTENSION_MD`.
-pub const NOTE_FILE_EXTENSIONS_TXT: &[&str] = &["txtnote", "adoc", "asciidoc"];
+/// See also `FILENAME_EXTENSIONS_MD`.
+pub const FILENAME_EXTENSIONS_TXT: &[&str] = &["txtnote", "adoc", "asciidoc"];
 
 /// The present list contains file extensions of
 /// Tp-Note files for which no viewer is opened
 /// (unless Tp-Note is invoked with `--view`).
 ///
-/// See also `NOTE_FILE_EXTENSION_MD`.
-pub const NOTE_FILE_EXTENSIONS_NO_VIEWER: &[&str] = &["t2t", "textile", "twiki", "mediawiki"];
+/// See also `FILENAME_EXTENSIONS_MD`.
+pub const FILENAME_EXTENSIONS_NO_VIEWER: &[&str] = &["t2t", "textile", "twiki", "mediawiki"];
 
-/// Maximum length of a note's filename in bytes. If a filename template produces
-/// a longer string, it will be truncated.
-#[cfg(not(test))]
-pub const NOTE_FILENAME_LEN_MAX: usize =
-    // Most file system's limit.
-    255
-    // Additional separator.
-    - COPY_COUNTER_EXTRA_SEPARATOR.len()
-    // Additional copy counter.
-    - COPY_COUNTER_OPENING_BRACKETS.len() - 2 - COPY_COUNTER_CLOSING_BRACKETS.len()
-    // Extra spare bytes, in case the user's copy counter is longer.
-    - 6;
-#[cfg(test)]
-pub const NOTE_FILENAME_LEN_MAX: usize = 10;
+/// By default clipboard support is enabled, can be disabled
+/// in config file. A false value here will set ENABLE_EMPTY_CLIPBOARD to
+/// false.
+const CLIPBOARD_READ_ENABLED: bool = true;
+
+/// Should the clipboard be emptied when tp-note closes?
+/// Default value.
+const CLIPBOARD_EMPTY_ENABLED: bool = true;
 
 /// As all application logic is encoded in Tp-Note's templates, it does not know about field names.
 /// Nevertheless it is useful to identify at least one field as _the_ field that identifies a note
@@ -286,6 +321,58 @@ const TMPL_SYNC_FILENAME: &str = "\
 {{ fm_file_ext | default(value = path | ext) | prepend_dot }}\
 ";
 
+/// Default command line argument list when launching the web browser.
+/// The list is executed item by item until an installed web browser is found.
+/// Can be changed in config file.
+#[cfg(all(target_family = "unix", not(target_vendor = "apple")))]
+const APP_ARGS_BROWSER: &[&[&str]] = &[
+    &[
+        "flatpak",
+        "run",
+        "org.mozilla.firefox",
+        "--new-window",
+        "--private-window",
+    ],
+    &["firefox", "--new-window", "--private-window"],
+    &["firefox-esr", "--new-window", "--private-window"],
+    &[
+        "flatpak",
+        "run",
+        "com.github.Eloston.UngoogledChromium",
+        "--new-window",
+        "--incognito",
+    ],
+    &[
+        "flatpak",
+        "run",
+        "org.chromium.Chromium",
+        "--new-window",
+        "--incognito",
+    ],
+    &["chromium-browser", "--new-window", "--incognito"],
+    &["chrome", "--new-window", "--incognito"],
+];
+#[cfg(target_family = "windows")]
+const APP_ARGS_BROWSER: &[&[&str]] = &[
+    &[
+        "C:\\Program Files\\Mozilla Firefox\\firefox.exe",
+        "--new-window",
+        "--private-window",
+    ],
+    &[
+        "C:\\Program Files\\Google\\Chrome\\Application\\chrome",
+        "--new-window",
+        "--incognito",
+    ],
+    &[
+        "C:\\Program Files (x86)\\Microsoft\\Edge\\Application\\msedge.exe",
+        "--inprivate",
+    ],
+];
+// Some info about launching programs on iOS:
+//[dshell.pdf](https://www.stata.com/manuals13/dshell.pdf)
+#[cfg(all(target_family = "unix", target_vendor = "apple"))]
+const APP_ARGS_BROWSER: &[&[&str]] = &[];
 
 /// Default command line argument list when launching external editor.
 /// The editor list is executed item by item until an editor is found.
@@ -361,129 +448,59 @@ const APP_ARGS_EDITOR_CONSOLE: &[&[&str]] = &[
     &["vi"],
 ];
 
-/// Default command line argument list when launching the web browser.
-/// The list is executed item by item until an installed web browser is found.
-/// Can be changed in config file.
-#[cfg(all(target_family = "unix", not(target_vendor = "apple")))]
-const APP_ARGS_BROWSER: &[&[&str]] = &[
-    &[
-        "flatpak",
-        "run",
-        "org.mozilla.firefox",
-        "--new-window",
-        "--private-window",
-    ],
-    &["firefox", "--new-window", "--private-window"],
-    &["firefox-esr", "--new-window", "--private-window"],
-    &[
-        "flatpak",
-        "run",
-        "com.github.Eloston.UngoogledChromium",
-        "--new-window",
-        "--incognito",
-    ],
-    &[
-        "flatpak",
-        "run",
-        "org.chromium.Chromium",
-        "--new-window",
-        "--incognito",
-    ],
-    &["chromium-browser", "--new-window", "--incognito"],
-    &["chrome", "--new-window", "--incognito"],
-];
-#[cfg(target_family = "windows")]
-const APP_ARGS_BROWSER: &[&[&str]] = &[
-    &[
-        "C:\\Program Files\\Mozilla Firefox\\firefox.exe",
-        "--new-window",
-        "--private-window",
-    ],
-    &[
-        "C:\\Program Files\\Google\\Chrome\\Application\\chrome",
-        "--new-window",
-        "--incognito",
-    ],
-    &[
-        "C:\\Program Files (x86)\\Microsoft\\Edge\\Application\\msedge.exe",
-        "--inprivate",
-    ],
-];
-// Some info about launching programs on iOS:
-//[dshell.pdf](https://www.stata.com/manuals13/dshell.pdf)
-#[cfg(all(target_family = "unix", target_vendor = "apple"))]
-const APP_ARGS_BROWSER: &[&[&str]] = &[];
-
-/// By default clipboard support is enabled, can be disabled
-/// in config file. A false value here will set ENABLE_EMPTY_CLIPBOARD to
-/// false.
-const CLIPBOARD_READ_ENABLED: bool = true;
-
-/// Should the clipboard be emptied when tp-note closes?
-/// Default value.
-const CLIPBOARD_EMPTY_ENABLED: bool = true;
-
-/// If the stem of a filename ends with a pattern, that is similar
-/// to a copy counter, add this extra separator. Must be `-`, `_`
-/// or any combination of both. Shorter looks better.
-const COPY_COUNTER_EXTRA_SEPARATOR: &str = "-";
-
-/// Tp-Note may add a counter at the end of the filename when
-/// it can not save a file because the name is taken already.
-/// This is the opening bracket search pattern. Some examples:
-/// `"-"`, "'_'"", `"_-"`,`"-_"`, `"("`
-/// Can be empty.
-const COPY_COUNTER_OPENING_BRACKETS: &str = "(";
-
-/// Tp-Note may add a counter at the end of the filename when
-/// it can not save a file because the name is taken already.
-/// This is the closing bracket search pattern. Some examples:
-/// `"-"`, "'_'"", `"_-"`,`"-_"`, `"("`
-/// Can be empty.
-const COPY_COUNTER_CLOSING_BRACKETS: &str = ")";
-
-/// When a filename is taken already, Tp-Note adds a copy
-/// counter number in the range of `0..COPY_COUNTER_MAX`
-/// at the end.
-pub const COPY_COUNTER_MAX: usize = 400;
-
-/// HTML template to render the viewer-error page.
-pub const VIEWER_ERROR_TMPL: &str = r#"<!DOCTYPE html>
-<html lang="en">
-<head>
-<meta charset="UTF-8">
-<title>Syntax error</title>
-<style>
-.note-error { color: #523626; }
-pre { white-space: pre-wrap; }
-a { color: #316128; }
-h1, h2, h3, h4, h5, h6 { color: #d3af2c; font-family:sans-serif; }
-</style>
-</head>
-<body>
-<h3>Syntax error</h3>
-<p> in note file: <pre>{{ path }}</pre><p>
-<div class="note-error">
-<hr>
-<pre>{{ note_error }}</pre>
-<hr>
-</div>
-{{ note_erroneous_content }}
-<script>{{ note_js }}</script>
-</body>
-</html>
-"#;
-
-/// How often should the file watcher check for changes?
-/// Delay in milliseconds.
-const VIEWER_NOTIFY_PERIOD: u64 = 1000;
-
 /// Template used by the viewer to render error messages into html.
 /// When set to true, the viewer feature is automatically disabled when
 /// _Tp-Note_ encounters an `.md` file without header.  Experienced users can
 /// set this to `true`. See also `SILENTLY_IGNORE_MISSING_HEADER`.
 const VIEWER_MISSING_HEADER_DISABLES: bool = false;
 
+/// How often should the file watcher check for changes?
+/// Delay in milliseconds.
+const VIEWER_NOTIFY_PERIOD: u64 = 1000;
+
+/// Template used by the viewer to render a note into html.
+/// The maximum number of TCP connections the HTTP server can handle at the same
+/// time. In general, the serving and live update of the HTML rendition of the
+/// note file, requires normally 3 TCP connections: 1 old event channel (that is
+/// still open from the previous update), 1 TCP connection to serve the HTML,
+/// the local images (and referenced documents), and 1 new event channel.  In
+/// practise, stale connection are not always closed immediately. Hence 4 open
+/// connections are not uncommon.
+const VIEWER_TCP_CONNECTIONS_MAX: usize = 16;
+
+/// The first entry per line is the file extension in lowercase(!), the second the
+/// corresponding mime type.  Embedded files with types other than those listed
+/// here are silently ignored.  Note, that image files must be located in the
+/// same or in the note's parent directory.
+const VIEWER_SERVED_MIME_TYPES: &[&[&str]] = &[
+    &["apng", "image/apng"],
+    &["avif", "image/avif"],
+    &["bmp", "image/bmp"],
+    &["gif", "image/gif"],
+    &["html", "text/html"],
+    &["htm", "text/html"],
+    &["ico", "image/vnd.microsoft.icon"],
+    &["jpeg", "image/jpeg"],
+    &["jpg", "image/jpeg"],
+    &["pdf", "application/pdf"],
+    &["png", "image/png"],
+    &["svg", "image/svg+xml"],
+    &["tiff", "image/tiff"],
+    &["tif", "image/tiff"],
+    &["webp", "image/webp"],
+    &["mp3", "audio/mp3"],
+    &["ogg", "audio/ogg"],
+    &["oga", "audio/ogg"],
+    &["weba", "audio/webm"],
+    &["flac", "audio/flac"],
+    &["wav", "audio/wav"],
+    &["opus", "audio/opus"],
+    &["mp4", "video/mp4"],
+    &["ogv", "video/ogg"],
+    &["webm", "video/webm"],
+    &["ogx", "application/ogg"],
+];
+
 /// Served file types with corresponding mime types.  First entry per line is
 pub const VIEWER_RENDITION_TMPL: &str = r#"<!DOCTYPE html>
 <html lang="{{ fm_lang | default(value='en') }}">
@@ -549,48 +566,32 @@ h1, h2, h3, h4, h5, h6 { color: #263292; font-family:sans-serif; }
 </html>
 "#;
 
-/// the file extension in lowercase, the second the corresponding mime type.
-/// Embedded files with types other than those listed here are silently ignored.
-/// Note, that image files must be located in the same or in the note's parent
-/// directory.
-const VIEWER_SERVED_MIME_TYPES: &[&[&str]] = &[
-    &["apng", "image/apng"],
-    &["avif", "image/avif"],
-    &["bmp", "image/bmp"],
-    &["gif", "image/gif"],
-    &["html", "text/html"],
-    &["htm", "text/html"],
-    &["ico", "image/vnd.microsoft.icon"],
-    &["jpeg", "image/jpeg"],
-    &["jpg", "image/jpeg"],
-    &["pdf", "application/pdf"],
-    &["png", "image/png"],
-    &["svg", "image/svg+xml"],
-    &["tiff", "image/tiff"],
-    &["tif", "image/tiff"],
-    &["webp", "image/webp"],
-    &["mp3", "audio/mp3"],
-    &["ogg", "audio/ogg"],
-    &["oga", "audio/ogg"],
-    &["weba", "audio/webm"],
-    &["flac", "audio/flac"],
-    &["wav", "audio/wav"],
-    &["opus", "audio/opus"],
-    &["mp4", "video/mp4"],
-    &["ogv", "video/ogg"],
-    &["webm", "video/webm"],
-    &["ogx", "application/ogg"],
-];
-
-/// Template used by the viewer to render a note into html.
-/// The maximum number of TCP connections the HTTP server can handle at the same
-/// time. In general, the serving and live update of the HTML rendition of the
-/// note file, requires normally 3 TCP connections: 1 old event channel (that is
-/// still open from the previous update), 1 TCP connection to serve the HTML,
-/// the local images (and referenced documents), and 1 new event channel.  In
-/// practise, stale connection are not always closed immediately. Hence 4 open
-/// connections are not uncommon.
-const VIEWER_TCP_CONNECTIONS_MAX: usize = 16;
+/// HTML template to render the viewer-error page.
+pub const VIEWER_ERROR_TMPL: &str = r#"<!DOCTYPE html>
+<html lang="en">
+<head>
+<meta charset="UTF-8">
+<title>Syntax error</title>
+<style>
+.note-error { color: #523626; }
+pre { white-space: pre-wrap; }
+a { color: #316128; }
+h1, h2, h3, h4, h5, h6 { color: #d3af2c; font-family:sans-serif; }
+</style>
+</head>
+<body>
+<h3>Syntax error</h3>
+<p> in note file: <pre>{{ path }}</pre><p>
+<div class="note-error">
+<hr>
+<pre>{{ note_error }}</pre>
+<hr>
+</div>
+{{ note_erroneous_content }}
+<script>{{ note_js }}</script>
+</body>
+</html>
+"#;
 
 /// Template used to render a note into html when the
 /// rendition is saved to disk
@@ -664,14 +665,11 @@ pub struct Cfg {
     /// a text message explaining why we could not load the
     /// configuration file.
     pub version: String,
-    pub extension_default: String,
-    pub silently_ignore_missing_header: bool,
     pub arg_default: ArgDefault,
-    pub note_file_extensions: NoteFileExtensions,
+    pub filename: Filename,
+    pub clipboard: Clipboard,
     pub tmpl: Tmpl,
     pub app_args: AppArgs,
-    pub clipboard: Clipboard,
-    pub copy_counter: CopyCounter,
     pub viewer: Viewer,
     pub exporter: Exporter,
 }
@@ -685,14 +683,29 @@ pub struct ArgDefault {
     pub popup: bool,
 }
 
-/// Known note file extensions, deserialized from the configuration file.
+/// Configuration of filename parsing, deserialized from the
+/// configuration file.
 #[derive(Debug, Serialize, Deserialize)]
-pub struct NoteFileExtensions {
-    pub md: Vec<String>,
-    pub rst: Vec<String>,
-    pub html: Vec<String>,
-    pub txt: Vec<String>,
-    pub no_viewer: Vec<String>,
+pub struct Filename {
+    pub sort_tag_chars: String,
+    pub sort_tag_extra_separator: char,
+    pub copy_counter_extra_separator: String,
+    pub copy_counter_opening_brackets: String,
+    pub copy_counter_closing_brackets: String,
+    pub extension_default: String,
+    pub extensions_md: Vec<String>,
+    pub extensions_rst: Vec<String>,
+    pub extensions_html: Vec<String>,
+    pub extensions_txt: Vec<String>,
+    pub extensions_no_viewer: Vec<String>,
+}
+
+/// Configuration of clipboard behaviour, deserialized from the
+/// configuration file.
+#[derive(Debug, Serialize, Deserialize)]
+pub struct Clipboard {
+    pub read_enabled: bool,
+    pub empty_enabled: bool,
 }
 
 /// Filename templates and content templates, deserialized from the configuration file.
@@ -714,38 +727,21 @@ pub struct Tmpl {
 /// configuration file.
 #[derive(Debug, Serialize, Deserialize)]
 pub struct AppArgs {
+    pub browser: Vec<Vec<String>>,
     pub editor: Vec<Vec<String>>,
     pub editor_console: Vec<Vec<String>>,
-    pub browser: Vec<Vec<String>>,
-}
-
-/// Configuration of clipboard behaviour, deserialized from the
-/// configuration file.
-#[derive(Debug, Serialize, Deserialize)]
-pub struct Clipboard {
-    pub read_enabled: bool,
-    pub empty_enabled: bool,
-}
-
-/// Configuration of clipboard behaviour, deserialized from the
-/// configuration file.
-#[derive(Debug, Serialize, Deserialize)]
-pub struct CopyCounter {
-    pub extra_separator: String,
-    pub opening_brackets: String,
-    pub closing_brackets: String,
 }
 
 /// Configuration data for the viewer feature, deserialized from the
 /// configuration file.
 #[derive(Debug, Serialize, Deserialize)]
 pub struct Viewer {
-    pub error_tmpl: String,
-    pub notify_period: u64,
     pub missing_header_disables: bool,
-    pub rendition_tmpl: String,
-    pub served_mime_types: Vec<Vec<String>>,
+    pub notify_period: u64,
     pub tcp_connections_max: usize,
+    pub served_mime_types: Vec<Vec<String>>,
+    pub rendition_tmpl: String,
+    pub error_tmpl: String,
 }
 
 /// Configuration for the HTML exporter feature, deserialized from the
@@ -767,14 +763,11 @@ impl ::std::default::Default for Cfg {
 
         Cfg {
             version,
-            extension_default: EXTENSION_DEFAULT.to_string(),
-            silently_ignore_missing_header: SILENTLY_IGNORE_MISSING_HEADER,
             arg_default: ArgDefault::default(),
-            note_file_extensions: NoteFileExtensions::default(),
             tmpl: Tmpl::default(),
             app_args: AppArgs::default(),
             clipboard: Clipboard::default(),
-            copy_counter: CopyCounter::default(),
+            filename: Filename::default(),
             viewer: Viewer::default(),
             exporter: Exporter::default(),
         }
@@ -793,27 +786,33 @@ impl ::std::default::Default for ArgDefault {
     }
 }
 
-/// Default values for known note file extensions.
-impl ::std::default::Default for NoteFileExtensions {
+/// Default values for copy counter.
+impl ::std::default::Default for Filename {
     fn default() -> Self {
-        NoteFileExtensions {
-            md: NOTE_FILE_EXTENSIONS_MD
+        Filename {
+            sort_tag_chars: FILENAME_SORT_TAG_CHARS.to_string(),
+            sort_tag_extra_separator: FILENAME_SORT_TAG_EXTRA_SEPARATOR,
+            copy_counter_extra_separator: FILENAME_COPY_COUNTER_EXTRA_SEPARATOR.to_string(),
+            copy_counter_opening_brackets: FILENAME_COPY_COUNTER_OPENING_BRACKETS.to_string(),
+            copy_counter_closing_brackets: FILENAME_COPY_COUNTER_CLOSING_BRACKETS.to_string(),
+            extension_default: FILENAME_EXTENSION_DEFAULT.to_string(),
+            extensions_md: FILENAME_EXTENSIONS_MD
                 .iter()
                 .map(|a| (*a).to_string())
                 .collect(),
-            rst: NOTE_FILE_EXTENSIONS_RST
+            extensions_rst: FILENAME_EXTENSIONS_RST
                 .iter()
                 .map(|a| (*a).to_string())
                 .collect(),
-            html: NOTE_FILE_EXTENSIONS_HTML
+            extensions_html: FILENAME_EXTENSIONS_HTML
                 .iter()
                 .map(|a| (*a).to_string())
                 .collect(),
-            txt: NOTE_FILE_EXTENSIONS_TXT
+            extensions_txt: FILENAME_EXTENSIONS_TXT
                 .iter()
                 .map(|a| (*a).to_string())
                 .collect(),
-            no_viewer: NOTE_FILE_EXTENSIONS_NO_VIEWER
+            extensions_no_viewer: FILENAME_EXTENSIONS_NO_VIEWER
                 .iter()
                 .map(|a| (*a).to_string())
                 .collect(),
@@ -869,17 +868,6 @@ impl ::std::default::Default for Clipboard {
     }
 }
 
-/// Default values for copy counter.
-impl ::std::default::Default for CopyCounter {
-    fn default() -> Self {
-        CopyCounter {
-            extra_separator: COPY_COUNTER_EXTRA_SEPARATOR.to_string(),
-            opening_brackets: COPY_COUNTER_OPENING_BRACKETS.to_string(),
-            closing_brackets: COPY_COUNTER_CLOSING_BRACKETS.to_string(),
-        }
-    }
-}
-
 /// Default values for the viewer feature.
 impl ::std::default::Default for Viewer {
     fn default() -> Self {
@@ -931,6 +919,23 @@ lazy_static! {
 fn config_load_path(config_path: &Path) -> Result<Cfg, FileError> {
     if config_path.exists() {
         let config: Cfg = toml::from_str(&fs::read_to_string(config_path)?)?;
+        // Check for obvious configuration errors.
+        if config
+            .filename
+            .sort_tag_chars
+            .find(config.filename.sort_tag_extra_separator)
+            .is_some()
+        {
+            return Err(FileError::ConfigFileSortTag {
+                chars: config.filename.sort_tag_chars.escape_default().to_string(),
+                extra_separator: config
+                    .filename
+                    .sort_tag_extra_separator
+                    .escape_default()
+                    .to_string(),
+            });
+        }
+        // First check passed.
         Ok(config)
     } else {
         let mut buffer = File::create(config_path)?;
